@@ -10,6 +10,7 @@
 #' ft_merge <- flextable(mtcars)
 #' ft_merge <- merge_v(ft_merge, j = c("gear", "carb"))
 #' ft_merge
+#' @family flextable merging function
 #' @export
 merge_v <- function(x, j = NULL, part = "body" ){
   if( !inherits(x, "flextable") ) stop("set_header_labels supports only flextable objects.")
@@ -31,6 +32,7 @@ merge_v <- function(x, j = NULL, part = "body" ){
 #' @param x \code{flextable} object
 #' @param i rows where cells have to be merged.
 #' @param part partname of the table where merge has to be done.
+#' @family flextable merging function
 #' @examples
 #' dummy_df <- data.frame( col1 = letters,
 #' col2 = letters, stringsAsFactors = FALSE )
@@ -44,7 +46,6 @@ merge_h <- function(x, i = NULL, part = "body" ){
   part <- match.arg(part, c("body", "header", "footer"), several.ok = FALSE )
 
   i <- get_rows_id( x[[part]], i )
-
   x[[part]] <- span_rows(x = x[[part]], rows = i)
 
   x
@@ -57,6 +58,7 @@ merge_h <- function(x, i = NULL, part = "body" ){
 #'
 #' @param x \code{flextable} object
 #' @param part partname of the table where merge has to be done.
+#' @family flextable merging function
 #' @export
 #' @examples
 #' typology <- data.frame(
@@ -92,13 +94,15 @@ merge_none <- function(x, part = "all" ){
 
 
 
-#' @title Merge flextable cells
+#' @title Merge flextable cells into a single one
 #'
-#' @description Merge flextable cells
+#' @description Merge flextable cells into a single one. All
+#' rows and columns must be consecutive.
 #'
 #' @param x \code{flextable} object
 #' @param i,j columns and rows to merge
 #' @param part partname of the table where merge has to be done.
+#' @family flextable merging function
 #' @examples
 #' ft_merge <- flextable( head( mtcars ), cwidth = .5 )
 #' ft_merge <- merge_at( ft_merge, i = 1:2, j = 1:3 )
@@ -119,5 +123,39 @@ merge_at <- function(x, i = NULL, j = NULL, part = "body" ){
 }
 
 
+#' @title rowwise merge of a range of columns
+#'
+#' @description Merge flextable columns into a single one for each selected rows. All
+#' columns must be consecutive.
+#'
+#' @param x \code{flextable} object
+#' @param i selected rows
+#' @param j1,j2 selected columns that will define the range of columns to merge.
+#' @param part partname of the table where merge has to be done.
+#' @family flextable merging function
+#' @examples
+#' ft <- flextable( head( mtcars ), cwidth = .5 )
+#' ft <- merge_h_range( ft, i =  ~ cyl == 6, j1 = "am", j2 = "carb")
+#' ft
+#' @export
+merge_h_range <- function(x, i = NULL, j1 = NULL, j2 = NULL, part = "body" ){
+  if( !inherits(x, "flextable") ) stop("set_header_labels supports only flextable objects.")
+  part <- match.arg(part, c("body", "header", "footer"), several.ok = FALSE )
+
+  j1 <- get_columns_id(x[[part]], j = j1 )
+  j2 <- get_columns_id(x[[part]], j = j2 )
+
+  seq_cols <- j1:j2
+
+  i <- get_rows_id( x[[part]], i )
+  x[[part]]$spans$rows[ i, seq_cols] <- 0
+  x[[part]]$spans$rows[ i, j1] <- length(seq_cols)
+  check_merge(x[[part]])
+
+
+  x
+}
+
+
 
 
